@@ -47,6 +47,14 @@ def ANSI_ESCAPE_MODIFIERS():
         "INVERT": "7",
         "CONCEAL": "8",
         "STRIKETHROUGH": "9",
+        "BOLDOFF": "21",
+        "FAINTOFF": "22",
+        "ITALICOFF": "23",
+        "UNDERLINEOFF": "24",
+        "BLINKOFF": "25",
+        "INVERTOFF": "27",
+        "REVEALOFF": "28",
+        "STRIKETHROUGHOFF": "29",
     }
 
 
@@ -194,6 +202,14 @@ def ansi_reverse_style(style="default", return_style=False):
         "7": "INVERT_",
         "8": "CONCEAL_",
         "9": "STRIKETHROUGH_",
+        "21": "BOLDOFF_",
+        "22": "FAINTOFF_",
+        "23": "ITALICOFF_",
+        "24": "UNDERLINEOFF_",
+        "25": "BLINKOFF_",
+        "27": "INVERTOFF_",
+        "28": "REVEALOFF_",
+        "29": "STRIKETHROUGHOFF_",
         "38": "SET_FOREGROUND_",
         "48": "SET_BACKGROUND_",
         "38;2": "SET_FOREGROUND_FAINT_",
@@ -343,10 +359,23 @@ def ansi_color_escape_code_to_name(escape_code, style, reversed_style=None):
 
 def _bw_style():
     style = {
+        "NO_COLOR": "0",
         "BLACK": "0;30",
         "BLUE": "0;37",
         "CYAN": "0;37",
         "GREEN": "0;37",
+        "PURPLE": "0;37",
+        "RED": "0;37",
+        "WHITE": "0;37",
+        "YELLOW": "0;37",
+        "BACKGROUND_BLACK": "40",
+        "BACKGROUND_RED": "47",
+        "BACKGROUND_GREEN": "47",
+        "BACKGROUND_YELLOW": "47",
+        "BACKGROUND_BLUE": "47",
+        "BACKGROUND_PURPLE": "47",
+        "BACKGROUND_CYAN": "47",
+        "BACKGROUND_WHITE": "47",
         "INTENSE_BLACK": "0;90",
         "INTENSE_BLUE": "0;97",
         "INTENSE_CYAN": "0;97",
@@ -355,11 +384,6 @@ def _bw_style():
         "INTENSE_RED": "0;97",
         "INTENSE_WHITE": "0;97",
         "INTENSE_YELLOW": "0;97",
-        "NO_COLOR": "0",
-        "PURPLE": "0;37",
-        "RED": "0;37",
-        "WHITE": "0;37",
-        "YELLOW": "0;37",
     }
     return style
 
@@ -369,14 +393,14 @@ def _default_style():
         # Reset
         "NO_COLOR": "0",  # Text Reset
         # Regular Colors
-        "BLACK": "0;30",  # BLACK
-        "RED": "0;31",  # RED
-        "GREEN": "0;32",  # GREEN
-        "YELLOW": "0;33",  # YELLOW
-        "BLUE": "0;34",  # BLUE
-        "PURPLE": "0;35",  # PURPLE
-        "CYAN": "0;36",  # CYAN
-        "WHITE": "0;37",  # WHITE
+        "BLACK": "30",  # BLACK
+        "RED": "31",  # RED
+        "GREEN": "32",  # GREEN
+        "YELLOW": "33",  # YELLOW
+        "BLUE": "34",  # BLUE
+        "PURPLE": "35",  # PURPLE
+        "CYAN": "36",  # CYAN
+        "WHITE": "37",  # WHITE
         # Background
         "BACKGROUND_BLACK": "40",  # BLACK
         "BACKGROUND_RED": "41",  # RED
@@ -387,23 +411,23 @@ def _default_style():
         "BACKGROUND_CYAN": "46",  # CYAN
         "BACKGROUND_WHITE": "47",  # WHITE
         # High Intensity
-        "INTENSE_BLACK": "0;90",  # BLACK
-        "INTENSE_RED": "0;91",  # RED
-        "INTENSE_GREEN": "0;92",  # GREEN
-        "INTENSE_YELLOW": "0;93",  # YELLOW
-        "INTENSE_BLUE": "0;94",  # BLUE
-        "INTENSE_PURPLE": "0;95",  # PURPLE
-        "INTENSE_CYAN": "0;96",  # CYAN
-        "INTENSE_WHITE": "0;97",  # WHITE
+        "INTENSE_BLACK": "90",  # BLACK
+        "INTENSE_RED": "91",  # RED
+        "INTENSE_GREEN": "92",  # GREEN
+        "INTENSE_YELLOW": "93",  # YELLOW
+        "INTENSE_BLUE": "94",  # BLUE
+        "INTENSE_PURPLE": "95",  # PURPLE
+        "INTENSE_CYAN": "96",  # CYAN
+        "INTENSE_WHITE": "97",  # WHITE
         # High Intensity backgrounds
-        "BACKGROUND_INTENSE_BLACK": "0;100",  # BLACK
-        "BACKGROUND_INTENSE_RED": "0;101",  # RED
-        "BACKGROUND_INTENSE_GREEN": "0;102",  # GREEN
-        "BACKGROUND_INTENSE_YELLOW": "0;103",  # YELLOW
-        "BACKGROUND_INTENSE_BLUE": "0;104",  # BLUE
-        "BACKGROUND_INTENSE_PURPLE": "0;105",  # PURPLE
-        "BACKGROUND_INTENSE_CYAN": "0;106",  # CYAN
-        "BACKGROUND_INTENSE_WHITE": "0;107",  # WHITE
+        "BACKGROUND_INTENSE_BLACK": "100",  # BLACK
+        "BACKGROUND_INTENSE_RED": "101",  # RED
+        "BACKGROUND_INTENSE_GREEN": "102",  # GREEN
+        "BACKGROUND_INTENSE_YELLOW": "103",  # YELLOW
+        "BACKGROUND_INTENSE_BLUE": "104",  # BLUE
+        "BACKGROUND_INTENSE_PURPLE": "105",  # PURPLE
+        "BACKGROUND_INTENSE_CYAN": "106",  # CYAN
+        "BACKGROUND_INTENSE_WHITE": "107",  # WHITE
     }
     return style
 
