@@ -26,7 +26,7 @@ from xonsh.lazyimps import pygments, pyghooks
 from xonsh.imphooks import install_import_hooks
 from xonsh.events import events
 from xonsh.environ import xonshrc_context, make_args_env
-from xonsh.built_ins import XonshSession, load_builtins, load_proxies
+from xonsh.built_ins import XonshSession, load_builtins
 
 
 events.transmogrify("on_post_init", "LoadEvent")
@@ -447,6 +447,8 @@ def main_xonsh(args):
                 )
             else:
                 print("xonsh: {0}: No such file or directory.".format(args.file))
+                events.on_exit.fire()
+                sys.exit(1)
         elif args.mode == XonshMode.script_from_stdin:
             # run a script given on stdin
             code = sys.stdin.read()
@@ -485,10 +487,16 @@ def setup(
     threadable_predictors=(),
 ):
     """Starts up a new xonsh shell. Calling this in function in another
-    packages __init__.py will allow xonsh to be fully used in the
+    packages ``__init__.py`` will allow xonsh to be fully used in the
     package in headless or headed mode. This function is primarily indended to
     make starting up xonsh for 3rd party packages easier.
 
+    Here is example of using this at the top of an ``__init__.py``::
+
+        from xonsh.main import setup
+        setup()
+        del setup
+
     Parameters
     ----------
     ctx : dict-like or None, optional
@@ -513,7 +521,6 @@ def setup(
         execer = Execer(xonsh_ctx=ctx)
         builtins.__xonsh__ = XonshSession(ctx=ctx, execer=execer)
         load_builtins(ctx=ctx, execer=execer)
-        load_proxies()
         builtins.__xonsh__.shell = Shell(execer, ctx=ctx, shell_type=shell_type)
     builtins.__xonsh__.env.update(env)
     install_import_hooks()
