@@ -41,6 +41,7 @@ from xonsh.tools import (
     on_main_thread,
     XonshError,
     format_std_prepost,
+    ALIAS_KWARG_NAMES,
 )
 from xonsh.lazyasd import lazyobject, LazyObject
 from xonsh.jobs import wait_for_active_job, give_terminal_to, _continue
@@ -783,10 +784,10 @@ class PopenThread(threading.Thread):
 
     def _signal_int(self, signum, frame):
         """Signal handler for SIGINT - Ctrl+C may have been pressed."""
-        self.send_signal(signum)
+        self.send_signal(signal.CTRL_C_EVENT if ON_WINDOWS else signum)
         if self.proc is not None and self.proc.poll() is not None:
             self._restore_sigint(frame=frame)
-        if on_main_thread():
+        if on_main_thread() and not ON_WINDOWS:
             signal.pthread_kill(threading.get_ident(), signal.SIGINT)
 
     def _restore_sigint(self, frame=None):
@@ -1224,7 +1225,6 @@ def proxy_five(f, args, stdin, stdout, stderr, spec, stack):
 
 
 PROXIES = (proxy_zero, proxy_one, proxy_two, proxy_three, proxy_four, proxy_five)
-PROXY_KWARG_NAMES = frozenset(["args", "stdin", "stdout", "stderr", "spec", "stack"])
 
 
 def partial_proxy(f):
@@ -1236,7 +1236,7 @@ def partial_proxy(f):
             or param.kind == param.POSITIONAL_OR_KEYWORD
         ):
             numargs += 1
-        elif name in PROXY_KWARG_NAMES and param.kind == param.KEYWORD_ONLY:
+        elif name in ALIAS_KWARG_NAMES and param.kind == param.KEYWORD_ONLY:
             numargs += 1
     if numargs < 6:
         return functools.partial(PROXIES[numargs], f)
@@ -1245,7 +1245,7 @@ def partial_proxy(f):
         return f
     else:
         e = "Expected proxy with 6 or fewer arguments for {}, not {}"
-        raise XonshError(e.format(", ".join(PROXY_KWARG_NAMES), numargs))
+        raise XonshError(e.format(", ".join(ALIAS_KWARG_NAMES), numargs))
 
 
 class ProcProxyThread(threading.Thread):
@@ -1261,6 +1261,7 @@ class ProcProxyThread(threading.Thread):
         stdout=None,
         stderr=None,
         universal_newlines=False,
+        close_fds=False,
         env=None,
     ):
         """Parameters
@@ -1285,6 +1286,9 @@ class ProcProxyThread(threading.Thread):
             set to `None`, then `sys.stderr` is used.
         universal_newlines : bool, optional
             Whether or not to use universal newlines.
+        close_fds : bool, optional
+            Whether or not to close file descriptors. This is here for Popen
+            compatability and currently does nothing.
         env : Mapping, optional
             Environment mapping.
         """
@@ -1309,6 +1313,7 @@ class ProcProxyThread(threading.Thread):
         self.stdin = stdin
         self.stdout = stdout
         self.stderr = stderr
+        self.close_fds = close_fds
         self.env = env or builtins.__xonsh__.env
         self._interrupted = False
 
@@ -1658,6 +1663,7 @@ class ProcProxy(object):
         stdout=None,
         stderr=None,
         universal_newlines=False,
+        close_fds=False,
         env=None,
     ):
         self.orig_f = f
@@ -1669,6 +1675,7 @@ class ProcProxy(object):
         self.stdout = stdout
         self.stderr = stderr
         self.universal_newlines = universal_newlines
+        self.close_fds = close_fds
         self.env = env
 
     def poll(self):
